@@ -9,10 +9,11 @@ use Error::Pure qw(err);
 use List::Util qw(none);
 use Readonly;
 use Scalar::Util qw(blessed);
+use Tags::HTML::Messages;
 
 Readonly::Array our @FORM_METHODS => qw(post get);
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -67,6 +68,12 @@ sub new {
 		err "Texts for language '$self->{'lang'}' doesn't exist.";
 	}
 
+	$self->{'_tags_messages'} = Tags::HTML::Messages->new(
+		'css' => $self->{'css'},
+		'flag_no_messages' => 0,
+		'tags' => $self->{'tags'},
+	);
+
 	# Object.
 	return $self;
 }
@@ -75,14 +82,6 @@ sub new {
 sub _process {
 	my ($self, $messages_ar) = @_;
 
-	if (defined $messages_ar) {
-		foreach my $message (@{$messages_ar}) {
-			if (! blessed($message) || ! $message->isa('Data::Message::Simple')) {
-				err "Message must be a instance of 'Data::Message::Simple' object.";
-			}
-		}
-	}
-
 	my $username_id = 'username';
 	my $password1_id = 'password1';
 	my $password2_id = 'password2';
@@ -146,34 +145,7 @@ sub _process {
 		['e', 'fieldset'],
 	);
 
-	if (defined $messages_ar && @{$messages_ar}) {
-		$self->{'tags'}->put(
-			['b', 'div'],
-			['a', 'class', 'messages'],
-		);
-		my $count = 0;
-		foreach my $message (@{$messages_ar}) {
-			$count++;
-			if ($count > 1) {
-				$self->{'tags'}->put(
-					['b', 'br'],
-					['e', 'br'],
-				);
-			}
-			$self->{'tags'}->put(
-				['b', 'span'],
-				defined $message->lang
-					? (['a', 'lang', $message->lang])
-					: (),
-				['a', 'class', $message->type],
-				['d', $message->text],
-				['e', 'span'],
-			);
-		}
-		$self->{'tags'}->put(
-			['e', 'div'],
-		);
-	}
+	$self->{'_tags_messages'}->process($messages_ar);
 
 	$self->{'tags'}->put(
 		['e', 'form'],
@@ -186,10 +158,6 @@ sub _process {
 sub _process_css {
 	my ($self, $message_types_hr) = @_;
 
-	if (defined $message_types_hr && ref $message_types_hr ne 'HASH') {
-		err 'Message types must be a hash reference.';
-	}
-
 	$self->{'css'}->put(
 		['s', '.'.$self->{'css_register'}],
 		['d', 'width', $self->{'width'}],
@@ -248,13 +216,7 @@ sub _process_css {
 		['e'],
 	);
 
-	foreach my $message_type (keys %{$message_types_hr}) {
-		$self->{'css'}->put(
-			['s', '.'.$message_type],
-			['d', 'color', $message_types_hr->{$message_type}],
-			['e'],
-		);
-	}
+	$self->{'_tags_messages'}->process_css($message_types_hr);
 
 	return;
 }
@@ -381,7 +343,8 @@ Returns undef.
  process():
          From Tags::HTML::process():
                  Parameter 'tags' isn't defined.
-         Message must be a instance of 'Data::Message::Simple' object.
+         Bad message data object.
+         Text for lang '%s' and key '%s' doesn't exist.
 
  process_css():
          From Tags::HTML::process_css():
@@ -504,7 +467,8 @@ L<Class::Utils>,
 L<Error::Pure>,
 L<List::Util>,
 L<Readonly>,
-L<Tags::HTML>.
+L<Tags::HTML>,
+L<Tags::HTML::Messages>.
 
 =head1 SEE ALSO
 
@@ -538,6 +502,6 @@ BSD 2-Clause License
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
